aboutsummaryrefslogtreecommitdiffstats
path: root/src/dabOutput/edi/PFT.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dabOutput/edi/PFT.h')
-rw-r--r--src/dabOutput/edi/PFT.h9
1 files changed, 3 insertions, 6 deletions
diff --git a/src/dabOutput/edi/PFT.h b/src/dabOutput/edi/PFT.h
index 02380ec..1d09c0b 100644
--- a/src/dabOutput/edi/PFT.h
+++ b/src/dabOutput/edi/PFT.h
@@ -40,7 +40,7 @@
#include "Log.h"
#include "ReedSolomon.h"
-typedef std::vector<uint8_t> RSPacket;
+typedef std::vector<uint8_t> RSBlock;
typedef std::vector<uint8_t> PFTFragment;
class PFT
@@ -54,7 +54,6 @@ class PFT
m_k(RSDataWordLength),
m_m(NumRecoverableFragments),
m_pseq(0),
- m_encoder(m_k + ParityBytes, m_k),
m_verbose(verbose)
{
if (m_k > 207) {
@@ -76,9 +75,9 @@ class PFT
std::vector< PFTFragment > Assemble(AFPacket af_packet);
// Apply Reed-Solomon FEC to the AF Packet
- RSPacket Protect(AFPacket af_packet);
+ RSBlock Protect(AFPacket af_packet);
- // Cut a RSPacket into several fragments that can be transmitted
+ // Cut a RSBlock into several fragments that can be transmitted
std::vector< std::vector<uint8_t> > ProtectAndFragment(AFPacket af_packet);
private:
@@ -89,8 +88,6 @@ class PFT
size_t m_num_chunks;
- ReedSolomon m_encoder;
-
bool m_verbose;
};